@@ -7,6 +7,8 @@ log = logging.getLogger()
 
 class InstalledApps(SettingsComponent):
     def create(self):
+        exported_values = ["ALLOWED_HOSTS", "DATABASES"]
+
         red = self.parse()
         apps_list = red.find("name", value="INSTALLED_APPS").parent.value
 
@@ -14,7 +16,16 @@ class InstalledApps(SettingsComponent):
         apps_list.append("'rest_framework'")
 
         log.info("Adding backend app to installed apps")
-        apps_list.append("'backend'")
+        apps_list.append("'zygoat_django'")
+
+        log.info("Removing default components exported by zygoat_django")
+
+        for value in exported_values:
+            index = red.find("name", value=value).parent.index_on_parent
+
+            # Delete the blank line following it as well
+            del red[index]
+            del red[index]
 
         log.info("Dumping installed apps node")
         self.dump(red)
@@ -22,7 +33,10 @@ class InstalledApps(SettingsComponent):
     @property
     def installed(self):
         red = self.parse()
-        return "backend" in red.find("name", value="INSTALLED_APPS").parent.value.to_python()
+        return (
+            "zygoat_django"
+            in red.find("name", value="INSTALLED_APPS").parent.value.to_python()
+        )
 
 
 installed_apps = InstalledApps()
