@@ -7,13 +7,15 @@ from zygoat.utils.shell import run
 from zygoat.utils.files import use_dir
 
 from .mui import mui
+from .jest_config import jest_config
+from .jest_setup import jest_setup
 
 log = logging.getLogger()
 
 
 class Dependencies(Component):
     dependencies = ["prop-types", "axios", "next-compose-plugins", "next-svgr", "next-images"]
-    dev_dependencies = ["jest", "@testing-library/dom", "@testing-library/react"]
+    dev_dependencies = ["jest", "react-axe", "@testing-library/dom", "@testing-library/react"]
 
     def create(self):
         with use_dir(Projects.FRONTEND):
@@ -23,6 +25,16 @@ class Dependencies(Component):
             log.info("Installing frontend dev dependencies")
             run(["yarn", "add", "--dev", *self.dev_dependencies])
 
+            log.info("Adding jest test commands")
+            with open("package.json") as f:
+                data = json.load(f)
+                data["scripts"]["test"] = "jest"
+                data["scripts"]["test-coverage"] = "jest --coverage"
+
+            log.info("Dumping new frontend package file")
+            with open("package.json", "w") as f:
+                json.dump(data, f)
+
     def update(self):
         self.call_phase(Phases.CREATE, force_create=True)
         with use_dir(Projects.FRONTEND):
@@ -49,4 +61,4 @@ class Dependencies(Component):
                 return True
 
 
-dependencies = Dependencies(sub_components=[mui])
+dependencies = Dependencies(sub_components=[mui, jest_config, jest_setup])
