@@ -9,5 +9,9 @@ def run(cmd, *args, **kwargs):
     :param cmd: An iterable object with strings inside that form a command
     """
     return subprocess.run(
-        " ".join([shlex.quote(c) for c in cmd]), *args, shell=True, check=True, **kwargs,
+        " ".join([shlex.quote(c) for c in cmd]),
+        *args,
+        shell=True,
+        check=True,
+        **kwargs,
     )
